Data class

Constructors

Data({String? id, String? clientReferenceId, int? amount, String? currency, String? paymentMethod, NextAction? nextAction, String? status, Map<String, dynamic>? metadata, DateTime? createdAt, DateTime? expireAt})
Data.fromJson(Map<String, dynamic> json)
factory

Properties

amount ↔ int?
getter/setter pair
clientReferenceId ↔ String?
getter/setter pair
createdAt ↔ DateTime?
getter/setter pair
currency ↔ String?
getter/setter pair
expireAt ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
getter/setter pair
metadata ↔ Map<String, dynamic>?
getter/setter pair
nextAction ↔ NextAction?
getter/setter pair
paymentMethod ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
getter/setter pair

Methods

copyWith({String? id, String? clientReferenceId, int? amount, String? currency, String? paymentMethod, NextAction? nextAction, String? status, Map<String, dynamic>? metadata, DateTime? createdAt, DateTime? expireAt}) → Data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited