CreatePaymentModel class

Constructors

CreatePaymentModel({bool? success, int? code, String? description, Data? data})
CreatePaymentModel.fromJson(Map<String, dynamic> json)
factory

Properties

code ↔ int?
getter/setter pair
data ↔ Data?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
getter/setter pair

Methods

copyWith({bool? success, int? code, String? description, Data? data}) → CreatePaymentModel
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited