StatusClass class

Constructors

StatusClass({bool? success, int? code, Map? data, String? description, Map? metadata})
StatusClass.fromJson(Map<String, dynamic> json)

Properties

code ↔ int?
getter/setter pair
data ↔ Map?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited